#
# spec file for package callaudiod
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname libcallaudio0_1-0
%define apiver 0.1

Name:           callaudiod
Version:        0.1.9
Release:        1.2
Summary:        Daemon for audio calls
License:        GPL-3.0-or-later AND MIT
URL:            https://gitlab.com/mobian1/callaudiod
Source0:        %{name}-%{version}.tar.xz

BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  gtkdoc
BuildRequires:  meson
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(folks)
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gom-1.0)
BuildRequires:  pkgconfig(gsound)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libebook-contacts-1.2)
BuildRequires:  pkgconfig(libfeedback-0.0)
BuildRequires:  pkgconfig(libhandy-1)
BuildRequires:  pkgconfig(libpeas-1.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(mm-glib)

%description
A daemon for audio calls.

%package -n %{soname}
Summary:        Shared library files for %{name}

%description -n %{soname}
A daemon for audio calls.
This package contains the shared library files for %{name}.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}
Requires:       %{soname} = %{version}

%description devel
A daemon for audio calls.
This package contains the development and header files for %{name}.

%package doc
Summary:        API documentation for %{name}
BuildArch:      noarch

%description doc
A daemon for audio calls.
This package contains API documentation for %{name}.

%prep
%autosetup

%build
%meson \
	-Dgtk_doc=true \
	%{nil}
%meson_build

%install
%meson_install

%check
%meson_test

%ldconfig_scriptlets -n %{soname}

%files
%license COPYING
%{_bindir}/callaudiocli
%{_bindir}/callaudiod
%{_datadir}/dbus-1/interfaces/org.mobian_project.CallAudio.xml
%{_datadir}/dbus-1/services/org.mobian_project.CallAudio.service

%files -n %{soname}
%{_libdir}/libcallaudio-%{apiver}.so.*

%files devel
%{_includedir}/libcallaudio-%{apiver}/
%{_libdir}/libcallaudio-%{apiver}.so
%{_libdir}/pkgconfig/libcallaudio-%{apiver}.pc

%files doc
%{_datadir}/gtk-doc/html/libcallaudio/

%changelog
* Fri Sep  1 2023 andrea.manzini@suse.com
- Update to version 0.1.9:
  * Release version 0.1.9
  * cad-pulse: don't filter input ports based on type
  * Release version 0.1.8
  * cad-pulse: also accept "Handset" type input ports
* Fri Mar  3 2023 andrea.manzini@suse.com
- Update to version 0.1.7:
  * Release version 0.1.7
  * libcallaudio: Properly handle successful return code
  * Release version 0.1.6
  * libcallaudio: Set error in sync API if unsuccessful
  * libcallaudio: Drop DBus method return value in sync and async functions
  * libcallaudio: Make logging consistent between sync and async API
  * libcallaudio: Distinguish DBus error from unsuccessful operations
  * libcallaudio: Prefer using FALSE instead of 0
  * Release version 0.1.5
  * cad-pulse: relax card filtering even more
  * cad-pulse: stop polling for new cards
  * cad-pulse: relax card filtering
  * cad-pulse: fix segfault when there is no target port
  * cad-manager: Don't return error on unsuccessful operations
  * cad-manager: Return TRUE when returning error for DBus method invocation
  * libcallaudio: Fix typo in documentation
  * build: Enable more warnings
  * cad-manager: Avoid magic constant
  * cli: return non zero exit status on failure
* Thu Sep  1 2022 bjorn.lie@gmail.com
- Update to version 0.1.4:
  * cad-pulse:
  - Fix possible NULL dereference
  - Improve monitor source identification
  - Make sure speaker state is reset between calls
  - Set D-Bus object properties on state change
  - Simplify mic mute operation
  - Track current state
  * cli: Add --status flag to query current status
  * dbus: Add properties to track the current state
  * gitlab-ci: add `debian` folder for CI use
  * libcallaudio:
  - Add API to query current state
  - Don't leak async data
  - Improve documentation and fix more leaks
  - Register enums as GType
  - Use G_DBUS_PROXY_FLAGS_NONE instead of "0"
  * manager:
  - Add DBus properties
  - Remove unused code
  - Track state of operations
  * src: make backend responsible for tracking current state
- Package doc sub-package as noarch.
- Add apiver define, ease future changes.
* Mon Jan 31 2022 bjorn.lie@gmail.com
- Update to version 0.1.3:
  * cad-pulse: don't switch ports on non-default sink/source
  * cad-pulse: consider "Handset" port as "Earpiece"
  * cad-pulse: fix card retry timer
  * cad-pulse: make new sink/source the default one
  * cad-pulse: filter out monitor sources
- Changes from version 0.1.2:
  * cad-pulse: filter card based on available ports
  * cad-pulse: add additional check for discarding the modem
- Changes from version 0.1.1:
  * cad-pulse: don't assume card bus path is exactly
    "platform-sound"
- Change service to use buildtime tarball generation, use
  cpioformat for source, and enable changes generated from gitlog,
  as upstream do not produce NEWS or release notes. Also switch to
  explicit set release tag for revision, we like to know what we
  pulling down, and be sure it will be the same each time.
- Split out shared library in own package, name it after its
  soname, follow the SLPP!
- Use generic names for compilers BuildRequired, and generally tidy
  up the specfile.
* Sun Apr 11 2021 Andrés B.S. <andresbs@opensuse.org>
- Improve packaging: split devel files, remove unnecesary buildreqs
  and build API docs.
* Tue Feb 23 2021 Adrian Campos Garrido <adriancampos@teachelp.com>
- Update to 0.1.0
